# ML-Dash Enhancement Plans

Main Objectives
1. run-management: monitor, kill, relaunch runs.
2. better UI (lean, no-bullshit, exploratory)

## Todo List

- [ ] comment out the 
- [ ] Add keyword glob to the keys
- [ ] parallel coordinates
